@@ -36,7 +36,7 @@ class Tracker:
               metrics: Optional[Dict[str, Any]] = None,
               tags: Optional[Dict[str, str]] = None):
         if artifact_file_paths:
-            self.__track_artifacts(artifact_file_paths=artifact_file_paths)
+            self.track_artifacts(artifact_file_paths=artifact_file_paths)
         if parameters:
             for parameter_name, parameter_value in parameters.items():
                 mlflow.log_param(parameter_name, parameter_value)
@@ -53,19 +53,40 @@ class Tracker:
             for tag_name, tag_value in tags.items():
                 mlflow.set_tag(tag_name, tag_value)
 
-    def __track_artifacts(self, artifact_file_paths: List[str]):
+    def track_artifacts(self, artifact_file_paths: List[str]):
         for artifact_file_path in artifact_file_paths:
             if os.path.isdir(artifact_file_path):
                 artifact_file_path = self.__zip_dir(dir_path=artifact_file_path)
-            self.__track_artifact_file(artifact_file_path)
+            self.track_artifact_file(artifact_file_path)
 
-    def __track_artifact_file(self, artifact_file_path: str):
-        mlflow_artifact_path: str = \
-            artifact_file_path[len(self.__artifact_root_path):-len(basename(artifact_file_path))]
-        mlflow_artifact_path = mlflow_artifact_path.strip(sep)  # remove leading and trailing / or \
+    def track_artifact_file(self, artifact_file_path: str, mlflow_artifact_dir_path: Optional[str] = None) -> str:
+        """
+        :param artifact_file_path: Local path to the file to write.
+        :param mlflow_artifact_dir_path: If provided, the directory in ``artifact_uri`` to write to.
+                                     If not provided, the directory will be derived
+        :return: the MLflow artifact file path
+        """
+        if mlflow_artifact_dir_path is None:
+            if artifact_file_path.startswith(self.__artifact_root_path):
+                mlflow_artifact_dir_path: str = \
+                    artifact_file_path[len(self.__artifact_root_path):-len(basename(artifact_file_path))]
+            else:
+                mlflow_artifact_dir_path = ""
+        mlflow_artifact_dir_path = mlflow_artifact_dir_path.strip(sep)  # remove leading and trailing / or \
         if self.__mlflow_repo_is_remote():
-            mlflow_artifact_path = mlflow_artifact_path.replace(sep, "/")  # replace Windows separator with S3 slash
-        mlflow.log_artifact(local_path=artifact_file_path, artifact_path=mlflow_artifact_path)
+            # replace local (e.g. Windows) separator with S3 slash
+            mlflow_artifact_dir_path = mlflow_artifact_dir_path.replace(sep, "/")
+        mlflow.log_artifact(local_path=artifact_file_path, artifact_path=mlflow_artifact_dir_path)
+        if len(mlflow_artifact_dir_path) > 0:
+            mlflow_artifact_file_path = f"{mlflow_artifact_dir_path}/{basename(artifact_file_path)}"
+        else:
+            mlflow_artifact_file_path = basename(artifact_file_path)
+        return mlflow_artifact_file_path
+
+    @staticmethod
+    def get_artifact_uri(mlflow_artifact_file_path: str) -> str:
+        uri: str = mlflow.get_artifact_uri(artifact_path=mlflow_artifact_file_path)
+        return uri
 
     @staticmethod
     def __zip_dir(dir_path: str) -> str:
